@@ -4,6 +4,8 @@
 #include <string>
 #include <stdexcept>
 
+namespace jags {
+
 class Distribution;
 
 /**
@@ -18,4 +20,6 @@ public:
     DistError(Distribution const *dist, std::string const &msg);
 };
 
+} /* namespace jags */
+
 #endif /* DIST_ERROR_H_ */
