@@ -5,6 +5,8 @@
 #include <distribution/VectorDist.h>
 #include <distribution/ArrayDist.h>
 
+namespace jags {
+
 /**
  * @short Polymorphic pointer to Distribution
  *
@@ -31,4 +33,6 @@ public:
     friend bool isNULL(DistPtr const &p);
 };
 
+} /* namespace jags */
+
 #endif /* DIST_POINTER_H_ */
