@@ -3,10 +3,12 @@
 
 #include <function/Function.h>
 
+namespace jags {
+
 /**
  * @short Scalar-valued Function with scalar arguments
  *
- * ScalarFunc represents scalar-valued functions whose parameters are
+ * ScalarFunction represents scalar-valued functions whose parameters are
  * also scalars. 
  */
 class ScalarFunction : public Function
@@ -42,4 +44,6 @@ public:
 		 std::vector<bool> const &isfixed) const;
 };
 
+} /* namespace jags */
+
 #endif /* SCALAR_FUNCTION_H_ */
