@@ -4,6 +4,8 @@
 #include <graph/LogicalNode.h>
 #include <vector>
 
+namespace jags {
+
 class ArrayFunction;
 
 /**
@@ -17,7 +19,7 @@ public:
      * A logical node is defined by a function (which may be an inline
      * operator in the BUGS language) and its parameters.
      */
-    ArrayLogicalNode(ArrayFunction const *func,
+    ArrayLogicalNode(ArrayFunction const *func, unsigned int nchain,
 		     std::vector<Node const*> const &parameters);
     /**
      * Calculates the value of the node based on the parameters. 
@@ -27,7 +29,9 @@ public:
      * @see ArrayFunction#checkParameterValue.
      */
     bool checkParentValues(unsigned int chain) const;
-    DeterministicNode *clone(std::vector<Node const *> const &parents) const;
+    //DeterministicNode *clone(std::vector<Node const *> const &parents) const;
 };
 
+} /* namespace jags */
+
 #endif /* ARRAY_LOGICAL_NODE_H_ */
