@@ -3,6 +3,8 @@
 
 #include <graph/StochasticNode.h>
 
+namespace jags {
+
 class ArrayDist;
 
 /**
@@ -15,23 +17,27 @@ class ArrayStochasticNode : public StochasticNode {
 	    unsigned int chain) const;
 public:
     /**
-     * Constructs a new StochasticNode given an array-valued
+     * Construct
      * distribution and an array of parent nodes, considered as
      * parameters to the distribution.
      */
-    ArrayStochasticNode(ArrayDist const *dist,
+    ArrayStochasticNode(ArrayDist const *dist, unsigned int nchain,
 			std::vector<Node const *> const &parameters,
-			Node const *lower, Node const *upper);
+			Node const *lower, Node const *upper,
+			double const *data=0, unsigned int length=0);
     double logDensity(unsigned int chain, PDFType type) const;
     void randomSample(RNG *rng, unsigned int chain);
     void truncatedSample(RNG *rng, unsigned int chain,
 			 double const *lower, double const *upper);
     void deterministicSample(unsigned int chain);
     bool checkParentValues(unsigned int chain) const;
-    StochasticNode *clone(std::vector<Node const *> const &parents,
-			  Node const *lower, Node const *upper) const;
+    //StochasticNode *clone(std::vector<Node const *> const &parents,
+    //Node const *lower, Node const *upper) const;
     unsigned int df() const;
+    double KL(unsigned int chain1, unsigned int chain2, RNG *rng, unsigned int nrep) const;
 };
 
+} /* namespace jags */
+
 #endif /* ARRAY_STOCHASTIC_NODE_H_ */
 
