@@ -4,6 +4,8 @@
 #include <graph/LogicalNode.h>
 #include <vector>
 
+namespace jags {
+
 class ScalarFunction;
 
 /**
@@ -20,7 +22,7 @@ public:
      * may be an inline operator in the BUGS language) and its
      * parameters.
      */
-    ScalarLogicalNode(ScalarFunction const *func,
+    ScalarLogicalNode(ScalarFunction const *func, unsigned int nchain,
 		      std::vector<Node const*> const &parameters);
     /**
      * Calculates the value of the node based on the parameters. 
@@ -30,7 +32,9 @@ public:
      * @see ScalarFunction#checkParameterValue.
      */
     bool checkParentValues(unsigned int chain) const;
-    DeterministicNode *clone(std::vector<Node const *> const &parents) const;
+    //DeterministicNode *clone(std::vector<Node const *> const &parents) const;
 };
 
+} /* namespace jags */ 
+
 #endif /* SCALAR_LOGICAL_NODE_H_ */
