@@ -1,8 +1,8 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 2005-6 Morten Welinder <terra@gnome.org>
- *  Copyright (C) 2005-6 The R Foundation
- *  Copyright (C) 2006	 The R Core Development Team
+ *  Copyright (C) 2005-10 The R Foundation
+ *  Copyright (C) 2006-10 The R Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,7 +43,6 @@
  *
  *	Complete redesign by Morten Welinder, originally for Gnumeric.
  *	Improvements (e.g. "while NEEDED_SCALE") by Martin Maechler
- *	The old version can be activated by compiling with -DR_USE_OLD_PGAMMA
  *
  *  REFERENCES
  *
@@ -240,12 +239,10 @@ double logspace_add (double logx, double logy)
  */
 double logspace_sub (double logx, double logy)
 {
-    return logx + log1p (-exp (logy - logx));
+    return logx + R_Log1_Exp(logy - logx);
 }
 
 
-#ifndef R_USE_OLD_PGAMMA
-
 /* dpois_wrap (x_P_1,  lambda, g_log) ==
  *   dpois (x_P_1 - 1, lambda, g_log) :=  exp(-L)  L^k / gamma(k+1) ,  k := x_P_1 - 1
 */
@@ -298,7 +295,7 @@ pgamma_smallx (double x, double alph, int lower_tail, int log_p)
     } while (fabs (term) > DBL_EPSILON * fabs (sum));
 
 #ifdef DEBUG_p
-    REprintf (" %d terms --> conv.sum=%g;", n, sum);
+    REprintf ("%5.0f terms --> conv.sum=%g;", n, sum);
 #endif
     if (lower_tail) {
 	double f1 = log_p ? log1p (sum) : 1 + sum;
@@ -352,13 +349,13 @@ pd_upper_series (double x, double y, int log_p)
 }
 
 /* Continued fraction for calculation of
- *    ???
- *  =  (y / d)	+  o(y/d)
+ *    scaled upper-tail F_{gamma}
+ *  ~=  (y / d) * [1 +  (1-y)/d +  O( ((1-y)/d)^2 ) ]
  */
 static double
 pd_lower_cf (double y, double d)
 {
-    double f = 0, of;
+    double f= 0.0 /* -Wall */, of, f0;
     double i, c2, c3, c4,  a1, b1,  a2, b2;
 
 #define	NEEDED_SCALE				\
@@ -374,16 +371,18 @@ pd_lower_cf (double y, double d)
 #ifdef DEBUG_p
     REprintf("pd_lower_cf(y=%.14g, d=%.14g)", y, d);
 #endif
-    if (y == 0 || (R_FINITE(y) && !R_FINITE(d))) /* includes d = Inf  or y = 0 */
-	return 0;
-    /* Needed, e.g. for  pgamma(10^c(100,295), shape= 1.1, log=TRUE) */
-    if(fabs(y - 1) < fabs(d) * 1e-20) {
+    if (y == 0) return 0;
+
+    f0 = y/d;
+    /* Needed, e.g. for  pgamma(10^c(100,295), shape= 1.1, log=TRUE): */
+    if(fabs(y - 1) < fabs(d) * DBL_EPSILON) { /* includes y < d = Inf */
 #ifdef DEBUG_p
 	REprintf(" very small 'y' -> returning (y/d)\n");
 #endif
-	return (y/d);
+	return (f0);
     }
 
+    if(f0 > 1.) f0 = 1.;
     c2 = y;
     c4 = d; /* original (y,d), *not* potentially scaled ones!*/
 
@@ -392,9 +391,7 @@ pd_lower_cf (double y, double d)
 
     while NEEDED_SCALE
 
-    /* if(a2 == 0) return 0;/\* just in case, e.g. d=y=0 *\/ */
-
-    i = 0;
+    i = 0; of = -1.; /* far away */
     while (i < max_it) {
 
 	i++;	c2--;	c3 = i * c2;	c4 += 2;
@@ -410,19 +407,15 @@ pd_lower_cf (double y, double d)
 	if NEEDED_SCALE
 
 	if (b2 != 0) {
-	    of = f;
 	    f = a2 / b2;
-#ifdef UP_TO_2009_11_07__NO_LONGER
-	    /* convergence check: relative; absolute for small f : */
-	    if (fabs (f - of) <= DBL_EPSILON * fmax2(1., fabs(f))) { .. }
-#endif
-	    /* convergence check */
-	    if (fabs(f - of) <= DBL_EPSILON * fabs(f)) {
+ 	    /* convergence check: relative; "absolute" for very small f : */
+	    if (fabs (f - of) <= DBL_EPSILON * fmax2(f0, fabs(f))) {
 #ifdef DEBUG_p
 		REprintf(" %g iter.\n", i);
 #endif
 		return f;
 	    }
+	    of = f;
 	}
     }
 
@@ -516,7 +509,7 @@ dpnorm (double x, int lower_tail, double lp)
 
 	return 1 / sum;
     } else {
-	double d = dnorm (x, 0, 1, FALSE);
+	double d = dnorm (x, 0., 1., FALSE);
 	return d / exp (lp);
     }
 }
@@ -706,7 +699,7 @@ double pgamma(double x, double alph, double scale, int lower_tail, int log_p)
 	return x;
 #endif
     if(alph == 0.) /* limit case; useful e.g. in pnchisq() */
-	return (x < 0) ? R_DT_0: R_DT_1;
+	return (x <= 0) ? R_DT_0: R_DT_1; /* <= assert  pgamma(0,0) ==> 0 */
     return pgamma_raw (x, alph, lower_tail, log_p);
 }
 /* From: terra@gnome.org (Morten Welinder)
@@ -725,161 +718,3 @@ double pgamma(double x, double alph, double scale, int lower_tail, int log_p)
 
  * MM: I've not (yet?) taken  logcf(), but the other four
  */
-
-
-#else
-/* R_USE_OLD_PGAMMA */
-/*
- *  Copyright (C) 1998		Ross Ihaka
- *  Copyright (C) 1999-2000	The R Development Core Team
- *  Copyright (C) 2003-2004	The R Foundation
- *  based on AS 239 (C) 1988 Royal Statistical Society
- *
- *  ................
- *
- *  NOTES
- *
- *	This function is an adaptation of Algorithm 239 from the
- *	Applied Statistics Series.  The algorithm is faster than
- *	those by W. Fullerton in the FNLIB library and also the
- *	TOMS 542 alorithm of W. Gautschi.  It provides comparable
- *	accuracy to those algorithms and is considerably simpler.
- *
- *  REFERENCES
- *
- *	Algorithm AS 239, Incomplete Gamma Function
- *	Applied Statistics 37, 1988.
- */
-
-/* now would need this here: */
-double attribute_hidden pgamma_raw(x, alph, lower_tail, log_p) {
-    return pgamma(x, alph, 1, lower_tail, log_p);
-}
-
-double pgamma(double x, double alph, double scale, int lower_tail, int log_p)
-{
-    const static double
-	xbig = 1.0e+8,
-	xlarge = 1.0e+37,
-
-	/* normal approx. for alph > alphlimit */
-	alphlimit = 1e5;/* was 1000. till R.1.8.x */
-
-    double pn1, pn2, pn3, pn4, pn5, pn6, arg, a, b, c, an, osum, sum;
-    long n;
-    int pearson;
-
-    /* check that we have valid values for x and alph */
-
-#ifdef IEEE_754
-    if (ISNAN(x) || ISNAN(alph) || ISNAN(scale))
-	return x + alph + scale;
-#endif
-#ifdef DEBUG_p
-    REprintf("pgamma(x=%4g, alph=%4g, scale=%4g): ",x,alph,scale);
-#endif
-    if(alph <= 0. || scale <= 0.)
-	ML_ERR_return_NAN;
-
-    x /= scale;
-#ifdef DEBUG_p
-    REprintf("-> x=%4g; ",x);
-#endif
-#ifdef IEEE_754
-    if (ISNAN(x)) /* eg. original x = scale = Inf */
-	return x;
-#endif
-    if (x <= 0.)
-	return R_DT_0;
-
-#define USE_PNORM \
-    pn1 = sqrt(alph) * 3. * (pow(x/alph, 1./3.) + 1. / (9. * alph) - 1.); \
-    return pnorm(pn1, 0., 1., lower_tail, log_p);
-
-    if (alph > alphlimit) { /* use a normal approximation */
-	USE_PNORM;
-    }
-
-    if (x > xbig * alph) {
-	if (x > DBL_MAX * alph)
-	    /* if x is extremely large __compared to alph__ then return 1 */
-	    return R_DT_1;
-	else { /* this only "helps" when log_p = TRUE */
-	    USE_PNORM;
-	}
-    }
-
-    if (x <= 1. || x < alph) {
-
-	pearson = 1;/* use pearson's series expansion. */
-
-	arg = alph * log(x) - x - lgammafn(alph + 1.);
-#ifdef DEBUG_p
-	REprintf("Pearson  arg=%g ", arg);
-#endif
-	c = 1.;
-	sum = 1.;
-	a = alph;
-	do {
-	    a += 1.;
-	    c *= x / a;
-	    sum += c;
-	} while (c > DBL_EPSILON * sum);
-    }
-    else { /* x >= max( 1, alph) */
-
-	pearson = 0;/* use a continued fraction expansion */
-
-	arg = alph * log(x) - x - lgammafn(alph);
-#ifdef DEBUG_p
-	REprintf("Cont.Fract. arg=%g ", arg);
-#endif
-	a = 1. - alph;
-	b = a + x + 1.;
-	pn1 = 1.;
-	pn2 = x;
-	pn3 = x + 1.;
-	pn4 = x * b;
-	sum = pn3 / pn4;
-	for (n = 1; ; n++) {
-	    a += 1.;/* =   n+1 -alph */
-	    b += 2.;/* = 2(n+1)-alph+x */
-	    an = a * n;
-	    pn5 = b * pn3 - an * pn1;
-	    pn6 = b * pn4 - an * pn2;
-	    if (fabs(pn6) > 0.) {
-		osum = sum;
-		sum = pn5 / pn6;
-		if (fabs(osum - sum) <= DBL_EPSILON * fmin2(1., sum))
-		    break;
-	    }
-	    pn1 = pn3;
-	    pn2 = pn4;
-	    pn3 = pn5;
-	    pn4 = pn6;
-	    if (fabs(pn5) >= xlarge) {
-		/* re-scale the terms in continued fraction if they are large */
-#ifdef DEBUG_p
-		REprintf(" [r] ");
-#endif
-		pn1 /= xlarge;
-		pn2 /= xlarge;
-		pn3 /= xlarge;
-		pn4 /= xlarge;
-	    }
-	}
-    }
-
-    arg += log(sum);
-
-    lower_tail = (lower_tail == pearson);
-
-    if (log_p && lower_tail)
-	return(arg);
-    /* else */
-    /* sum = exp(arg); and return   if(lower_tail) sum	else 1-sum : */
-    return (lower_tail) ? exp(arg) : (log_p ? R_Log1_Exp(arg) : -expm1(arg));
-}
-
-#endif
-/* R_USE_OLD_PGAMMA */
