@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000 The R Development Core Team
+ *  Copyright (C) 2000 The R Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 
 #include "nmath.h"
 
-double rnorm(double mu, double sigma, RNG *rng)
+double rnorm(double mu, double sigma, JRNG *rng)
 {
     if (ISNAN(mu) || !R_FINITE(sigma) || sigma < 0.)
 	ML_ERR_return_NAN;
