@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000 The R Development Core Team
+ *  Copyright (C) 2000 The R Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  */
 #include "nmath.h"
 
-double runif(double a, double b, RNG *rng)
+double runif(double a, double b, JRNG *rng)
 {
     if (!R_FINITE(a) || !R_FINITE(b) || b < a)	ML_ERR_return_NAN;
 
