@@ -35,6 +35,30 @@ using std::set;
 using std::pair;
 using std::FILE;
 
+// Need to distinguish between errors that delete the model
+// and errors that don't delete the model (in update)
+// so that we can then dump parameter values from parser.cc
+#define CATCH_ERRORS_DUMP						\
+    catch (ParentError const &except) {					\
+        except.printMessage(_err, _model->symtab());			\
+	return false;							\
+    }									\
+    catch (NodeError const &except) {					\
+        except.printMessage(_err, _model->symtab());			\
+	return false;							\
+    }									\
+    catch (std::runtime_error const &except) {				\
+	_err << "RUNTIME ERROR:\n";					\
+	_err << except.what() << endl;					\
+	return false;							\
+    }									\
+    catch (std::logic_error const &except) {				\
+	_err << "LOGIC ERROR:\n" << except.what() << '\n';		\
+	_err << "Please send a bug report to "				\
+	     << PACKAGE_BUGREPORT << endl;				\
+	return false;							\
+    }
+
 #define CATCH_ERRORS							\
     catch (ParentError const &except) {					\
         except.printMessage(_err, _model->symtab());			\
@@ -378,7 +402,7 @@ bool Console::update(unsigned int n)
     try {
 	_model->update(n);
     }
-    CATCH_ERRORS;
+    CATCH_ERRORS_DUMP;
 
     return true;
 }
@@ -505,6 +529,7 @@ bool Console::dumpState(map<string,SArray> &data_table,
     }
   }
   CATCH_ERRORS;
+  // Model is subsequently cleared by calling functions in parser
   
   return true;
 }
