@@ -4,7 +4,11 @@
 
 using std::string;
 
+namespace jags {
+
 DistError::DistError(Distribution const *edist, string const &emsg)
     : runtime_error(emsg + " in distribution " + edist->name())
 {
 }
+
+} //namespace jags
