@@ -3,6 +3,8 @@
 
 using std::string;
 
+namespace jags {
+
 LinkFunction::LinkFunction (string const &name, string const &link)
     : Function (name, 1), _link(link)
 {
@@ -13,3 +15,4 @@ string const & LinkFunction::linkName () const
     return _link;
 }
 
+} //namespace jags
