@@ -7,6 +7,8 @@
 using std::invalid_argument;
 using std::string;
 
+namespace jags {
+
 MonitorControl::MonitorControl (Monitor *monitor, unsigned int start, 
 				unsigned int thin)
     : _monitor(monitor), _start(start), _thin(thin), _niter(0)
@@ -60,9 +62,4 @@ bool MonitorControl::operator==(MonitorControl const &rhs) const
 	    _niter == rhs._niter);
 }
 
-void MonitorControl::reserve(unsigned int niter)
-{
-    _monitor->reserve(niter/_thin + 1);
-}
-
-
+} //namespace jags
