@@ -1,6 +1,7 @@
 #include <config.h>
 #include <sampler/Linear.h>
 #include <sampler/GraphView.h>
+#include <sampler/SingletonGraphView.h>
 #include <graph/GraphMarks.h>
 #include <graph/Graph.h>
 #include <graph/StochasticNode.h>
@@ -10,6 +11,9 @@
 
 using std::vector;
 using std::set;
+using std::list;
+
+namespace jags {
 
 typedef bool (DeterministicNode::*NodeCheckFn) (GraphMarks const&, bool) const;
 
@@ -18,22 +22,81 @@ static bool isLink(DeterministicNode const *dnode)
     return dynamic_cast<LinkNode const*>(dnode) != 0;
 }
 
+    bool checkAdditive(SingletonGraphView const *sgv, bool fixed)
+    {
+	vector<DeterministicNode *> const &dn =	sgv->deterministicChildren();
+	set<Node const*> ancestors;
+	ancestors.insert(sgv->node());
+	for (unsigned int i = 0; i < dn.size(); ++i) {
+	    if(dn[i]->isClosed(ancestors, DNODE_ADDITIVE, fixed)) {
+		ancestors.insert(dn[i]);
+	    }
+	    else {
+		return false;
+	    }
+	}
+	return true;
+    }
+
+    bool checkAdditive(vector<StochasticNode*> const &snodes,
+		       Graph const &graph, bool fixed)
+    {
+	//A GraphView is additive if every SingletonGraphview for each
+	//sampled node in the same graph is additive.
+	for (unsigned int i = 0; i < snodes.size(); ++i) {
+	    SingletonGraphView sgv(snodes[i], graph);
+	    if (!checkAdditive(&sgv, false)) return false;
+	}
+
+	if (!fixed) return true;
+
+	//If we want to ensure that the additive function has a fixed
+	//intercept, we need to ensure that all parent nodes of
+	//deterministic children are either additive nodes themselves
+	//or are fixed.
+	
+	set<Node const*> ancestors;
+	//Sampled nodes are trivial (fixed) additive functions of themselves
+#ifndef _RWSTD_NO_MEMBER_TEMPLATES
+	ancestors.insert(snodes.begin(), snodes.end());
+#else
+	//Workaround for Solaris libCstd
+	for (vector<StochasticNode*>::const_iterator p =
+		 snodes.begin(); p != snodes.end(); ++p)
+	{
+	    ancestors.insert(*p);
+	}
+#endif
+
+	GraphView gv(snodes, graph);
+	vector<DeterministicNode *> const &dn =	gv.deterministicChildren();
+	for (unsigned int j = 0; j < dn.size(); ++j) {
+	    vector<Node const *> parj = dn[j]->parents();
+	    for (unsigned int k = 0; k < parj.size(); ++k) {
+		if (ancestors.count(parj[k]) == 0 && !parj[k]->isFixed()) {
+		    return false;
+		}
+	    }
+	    ancestors.insert(dn[j]);
+	}
+	return true;
+    }
+    
 bool checkLinear(GraphView const *gv, bool fixed, bool link)
 {
-    vector<StochasticNode const *> const &sn = gv->stochasticChildren();
     vector<DeterministicNode *> const &dn = gv->deterministicChildren();
 
     set<Node const*> ancestors;
     //Sampled nodes are trivial (fixed) linear functions of themselves
-#ifdef _RWSTD_NO_MEMBER_TEMPLATES
+#ifndef _RWSTD_NO_MEMBER_TEMPLATES
+    ancestors.insert(gv->nodes().begin(), gv->nodes().end());
+#else
     //Workaround for Solaris libCstd
     for (vector<StochasticNode const *>::const_iterator p = gv->nodes().begin();
          p != gv->nodes().end(); ++p)
       {
         ancestors.insert(*p);
       }
-#else
-    ancestors.insert(gv->nodes().begin(), gv->nodes().end());
 #endif
     
     for (unsigned int j = 0; j < dn.size(); ++j) {
@@ -43,8 +106,19 @@ bool checkLinear(GraphView const *gv, bool fixed, bool link)
 	else if (link && isLink(dn[j])) {
 	    // A link function is allowed if no other deterministic
 	    // nodes in the GraphView depend on it.
+	    set<DeterministicNode*> dset;
+	    list<DeterministicNode*> const *dc = dn[j]->deterministicChildren();
+#ifndef _RWSTD_NO_MEMBER_TEMPLATES
+	    dset.insert(dc->begin(), dc->end());
+#else
+	    for (list<DeterministicNode*>::const_iterator p = dc->begin(); 
+		 p != dc->end(); ++p) 
+            {
+	        dset.insert(*p);
+	    }
+#endif
 	    for (unsigned int k = j + 1; k < dn.size(); ++k) {
-		if (dn[j]->deterministicChildren()->count(dn[k])) {
+		if (dset.count(dn[k])) {
 		    return false;
 		}
 	    }
@@ -109,15 +183,15 @@ bool checkPower(GraphView const *gv, bool fixed)
 {
     set<Node const*> ancestors;
 
-#ifdef _RWSTD_NO_MEMBER_TEMPLATES
+#ifndef _RWSTD_NO_MEMBER_TEMPLATES
+    ancestors.insert(gv->nodes().begin(), gv->nodes().end());
+#else
     //Workaround for Solaris libCstd
     for (vector<StochasticNode const *>::const_iterator p = gv->nodes().begin();
          p != gv->nodes().end(); ++p)
       {
         ancestors.insert(*p);
       }
-#else
-    ancestors.insert(gv->nodes().begin(), gv->nodes().end());
 #endif 
 
     vector<DeterministicNode *> const &dnodes = gv->deterministicChildren();    
@@ -132,3 +206,5 @@ bool checkPower(GraphView const *gv, bool fixed)
     
     return true;
 }
+
+} //namespace jags
