@@ -4,6 +4,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace base {
 
     Add::Add () : Infix ("+", 0)
@@ -24,6 +25,23 @@ namespace base {
 	return allTrue(mask);
     }
 
+    bool
+    Add::isAdditive(vector<bool> const &mask, vector<bool> const &fix) const
+    {
+	//There should be exactly one argument that is an additive function
+	bool found = false; //Have we found it yet?
+	for (unsigned int i = 0; i < mask.size(); ++i) {
+	    if (mask[i]) {
+		if (found) return false;
+		else found = true;
+	    }
+	    else if (!fix.empty() && !fix[i]) {
+		return false;
+	    }
+	}
+	return found;
+    }
+    
     bool Add::isLinear(vector<bool> const &mask, vector<bool> const &fix) const
     {
 	return true;
@@ -33,4 +51,5 @@ namespace base {
     {
 	return allTrue(mask);
     }
-}
+
+}}
