@@ -6,6 +6,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace base {
 
 GreaterThan::GreaterThan () : Infix (">")
@@ -22,4 +23,4 @@ bool GreaterThan::isDiscreteValued(vector<bool> const &mask) const
   return true;
 }
 
-}
+}}
