@@ -3,6 +3,7 @@
 
 #include "Infix.h"
 
+namespace jags {
 namespace base {
 
 /**
@@ -23,6 +24,6 @@ public:
     bool isDiscreteValued(std::vector<bool> const &mask) const;
 };
 
-}
+}}
 
 #endif /* FUNC_OR_H_ */
