@@ -8,6 +8,7 @@ using std::vector;
 using std::pow;
 using std::string;
 
+namespace jags {
 namespace base {
 
 Pow::Pow () : Infix ("^")
@@ -44,4 +45,5 @@ bool Pow::checkParameterValue(vector<double const *> const &args) const
         else
             return fix.empty() || fix[1];
     }
-}
+
+}}
