@@ -6,6 +6,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace bugs {
 
 DF::DF()
@@ -56,4 +57,4 @@ double DF::r(vector<double const *> const &par, RNG *rng) const
     return rF(*par[0], *par[1], rng);
 }
 
-}
+}}
