@@ -24,6 +24,7 @@ static unsigned int value(vector<double const *> const &par, unsigned int ncut)
     return ncut;
 }
 
+namespace jags {
 namespace bugs {
 
 DInterval::DInterval()
@@ -38,7 +39,7 @@ bool DInterval::isDiscreteValued(vector<bool> const &mask) const
 
 bool DInterval::checkParameterLength(vector<unsigned int> const &lengths) const
 {
-    return lengths[0] == 1;
+    return lengths[0] == 1 && lengths[1] >= 1;
 }
 
 bool DInterval::checkParameterValue(vector<double const *> const &par,
@@ -122,18 +123,13 @@ unsigned int DInterval::length(vector<unsigned int> const &params) const
     return 1;
 }
 
-double DInterval::KL(vector<double const *> const &par1,
-		     vector<double const *> const &par2,
+double DInterval::KL(vector<double const *> const &par0,
+		     vector<double const *> const &par1,
 		     vector<unsigned int> const &lengths) const
 {
+    unsigned int y0 = value(par0, NCUT(lengths));
     unsigned int y1 = value(par1, NCUT(lengths));
-    unsigned int y2 = value(par2, NCUT(lengths));
-    if (y1 == y2) {
-	return 0;
-    }
-    else {
-	return JAGS_POSINF;
-    }
+    return (y0 == y1) ? 0 : JAGS_POSINF;
 }
 
-}
+}}
