@@ -1,8 +1,9 @@
 #ifndef DPAR_H_
 #define DPAR_H_
 
-#include "RScalarDist.h"
+#include <distribution/RScalarDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -32,6 +33,6 @@ class DPar : public RScalarDist {
   bool isSupportFixed(std::vector<bool> const &fixmask) const;
 };
 
-}
+}}
 
 #endif /* DPAR_H_ */
