@@ -3,6 +3,7 @@
 
 #include <distribution/ScalarDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -31,10 +32,10 @@ class DUnif : public ScalarDist {
     bool checkParameterValue(std::vector<double const *> const &parameters)
 	const;
     bool isSupportFixed(std::vector<bool> const &fixmask) const;
-    double KL(std::vector<double const *> const &par1,
-	      std::vector<double const *> const &par2) const;
+    double KL(std::vector<double const *> const &par0,
+	      std::vector<double const *> const &par1) const;
 };
 
-}
+}}
 
 #endif /* DUNIF_H_ */
