@@ -3,6 +3,7 @@
 
 #include <function/ScalarFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -19,6 +20,6 @@ namespace bugs {
 	double evaluate(std::vector<double const *> const &args) const;
     };
 
-}
+}}
 
 #endif /* FUNC_COS_H_ */
