@@ -3,6 +3,7 @@
 
 #include <function/ScalarFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -15,6 +16,6 @@ namespace bugs {
 	double evaluate (std::vector <double const *> const &args) const;
     };
 
-}
+}}
 
 #endif /* FUNC_DROUND_H_ */
