@@ -3,6 +3,7 @@
 
 #include <function/LinkFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -23,6 +24,6 @@ namespace bugs {
 	double grad(double eta) const;
     };
 
-}
+}}
 
 #endif /* FUNC_ILOGIT_H_ */
