@@ -6,23 +6,24 @@
 
 using std::vector;
 
+namespace jags {
 namespace bugs {
 
-    InProd::InProd () : VectorFunction ("inprod", 2)
+    InProd::InProd () : ScalarVectorFunction ("inprod", 2)
     {
     }
 
-    void InProd::evaluate(double *x, vector<double const *> const &args,
-			  vector<unsigned int> const &lengths) const
+    double InProd::scalarEval(vector<double const *> const &args,
+			      vector<unsigned int> const &lengths) const
     {
         int one = 1, N = lengths[0];
-        *x = F77_DDOT(&N, args[0], &one, args[1], &one);
+        return F77_DDOT(&N, args[0], &one, args[1], &one);
     }
 
     bool 
     InProd::checkParameterLength (vector<unsigned int> const &lengths) const
     {
-	return (lengths[0] == lengths[1]);
+	return (lengths[0] > 0) && (lengths[0] == lengths[1]);
     }
 
     bool InProd::isDiscreteValued(vector<bool> const &mask) const
@@ -44,4 +45,5 @@ namespace bugs {
 	    return (mask[0] || fix[0]) && (mask[1] || fix[1]); 
         }
     }
-}
+
+}}
