@@ -3,6 +3,7 @@
 
 #include <function/ScalarFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -19,9 +20,9 @@ namespace bugs {
     public:
 	LogFact ();
 	double evaluate(std::vector<double const *> const &args) const;
-	bool checkScalarValue(std::vector<double const *> const &args) const;
+	bool checkParameterValue(std::vector<double const *> const &args) const;
     };
 
-}
+}}
 
 #endif /* FUNC_LOGFACT_H_ */
