@@ -1,13 +1,15 @@
 #ifndef CONJUGATE_METHOD_H_
 #define CONJUGATE_METHOD_H_
 
-#include <string>
+#include <sampler/ImmutableSampleMethod.h>
+
 #include <vector>
 
-class GraphView;
-class RNG;
-class Graph;
+namespace jags {
+
+class SingletonGraphView;
 class StochasticNode;
+struct RNG;
 
 namespace bugs {
 
@@ -24,20 +26,17 @@ enum ConjugateDist {
  */
 ConjugateDist getDist(StochasticNode const *snode);
 
-class ConjugateMethod
+class ConjugateMethod : public ImmutableSampleMethod
 {
 protected:
     const ConjugateDist _target_dist;
     const std::vector<ConjugateDist> _child_dist;
-    GraphView const *_gv;
+    SingletonGraphView const * const _gv;
 public:
-    ConjugateMethod(GraphView const *gv);
-    virtual ~ConjugateMethod();
-    virtual void update(unsigned int chain, RNG *rng) const = 0;
-    virtual std::string name() const = 0;
+    ConjugateMethod(SingletonGraphView const *gv);
 };
 
-}
+}}
 
 #endif /* CONJUGATE_METHOD_H_ */
 
