@@ -16,6 +16,8 @@ using std::string;
 //Initial step size
 #define STEP 1
 
+namespace jags {
+namespace bugs {
 
 //Pick a random integer between 0 and n - 1
 static int pick(int n, RNG *rng)
@@ -26,8 +28,6 @@ static int pick(int n, RNG *rng)
     return i - 1;
 }
 
-namespace bugs {
-
 DiscreteDSum::DiscreteDSum(GraphView const *gv, unsigned int chain)
     : RWDSum(gv, chain, STEP)
 {
@@ -52,9 +52,4 @@ void DiscreteDSum::step(vector<double> &value,
     value[c2 * nrow + r] -= inteps;
 }
 
-string DiscreteDSum::name() const
-{
-    return "DiscreteDSum";
-}
-
-}
+}}
