@@ -3,13 +3,15 @@
 
 #include <sampler/Metropolis.h>
 
-class GraphView;
+namespace jags {
+
+    class SingletonGraphView;
 
 namespace bugs {
 
 class MNormMetropolis : public Metropolis
 {
-    GraphView const *_gv;
+    SingletonGraphView const *_gv;
     unsigned int _chain;
     double *_mean;
     double *_var;
@@ -21,16 +23,15 @@ class MNormMetropolis : public Metropolis
     unsigned int _nstep;
     unsigned int _p_over_target;
 public:
-    MNormMetropolis(GraphView const *gv, unsigned int chain);
+    MNormMetropolis(SingletonGraphView const *gv, unsigned int chain);
     ~MNormMetropolis();
     void rescale(double p);
     void update(RNG *rng);
     bool checkAdaptation() const;
-    std::string name() const;
     void getValue(std::vector<double> &value) const;
     void setValue(std::vector<double> const &value);
 };
 
-}
+}}
 
 #endif /* MNORM_METROPOLIS_H_ */
