@@ -13,6 +13,9 @@
 using std::vector;
 using std::string;
 
+namespace jags {
+namespace bugs {
+
 //Pick a random integer between 0 and n - 1
 static int pick(int n, RNG *rng)
 {
@@ -22,8 +25,6 @@ static int pick(int n, RNG *rng)
     return i - 1;
 }
 
-namespace bugs {
-
 RealDSum::RealDSum(GraphView const *gv, unsigned int chain)
     : RWDSum(gv, chain, STEP)
 {
@@ -46,11 +47,4 @@ void RealDSum::step(vector<double> &value, unsigned int nrow,
     value[c2 * nrow + r] -= eps;
 }
 
-string RealDSum::name() const
-{
-    return "RealDSum";
-}
-
-}
-
-
+}}
