@@ -3,21 +3,21 @@
 
 #include "ConjugateMethod.h"
 
-class Node;
+namespace jags {
+
+    class Graph;
 
 namespace bugs {
 
 class TruncatedGamma : public ConjugateMethod {
-    double _shape;
-    Node const *_parent;
+    const double _exponent;
 public:
-    TruncatedGamma(GraphView const *gv);
+    TruncatedGamma(SingletonGraphView const *gv);
     ~TruncatedGamma();
     static bool canSample(StochasticNode *snode, Graph const &graph);
     void update(unsigned int chain, RNG *rng) const;
-    std::string name() const;
 };
 
-}
+}}
 
 #endif /* TRUNCATED_GAMMA_H_ */
