@@ -3,6 +3,8 @@
 
 #include <model/Monitor.h>
 
+namespace jags {
+
 class StochasticNode;
 
 namespace dic {
@@ -16,11 +18,10 @@ namespace dic {
 	std::vector<unsigned int> dim() const;
 	std::vector<double> const &value(unsigned int chain) const;
 	void update();
-	void reserve(unsigned int niter);
 	bool poolChains() const;
 	bool poolIterations() const;
     };
 
-}
+}}
 
 #endif /* DEVIANCE_MEAN_H_ */
