@@ -1,9 +1,6 @@
 #include "PDMonitorFactory.h"
 #include "PDMonitor.h"
 #include "PoptMonitor.h"
-#include "KLTab.h"
-#include "CalKLExact.h"
-#include "CalKLApprox.h"
 
 #include <model/BUGSModel.h>
 #include <graph/StochasticNode.h>
@@ -15,13 +12,9 @@ using std::set;
 using std::string;
 using std::vector;
 
+namespace jags {
 namespace dic {
 
-    static KL const *findKL(string const &name) {
-	static KLTab _kltab;
-	return _kltab.find(name);
-    }
-
     Monitor *PDMonitorFactory::getMonitor(string const &name,
 					  Range const &range,
 					  BUGSModel *model,
@@ -35,11 +28,11 @@ namespace dic {
 	    return 0;
 
 	if (!isNULL(range)) {
-	    msg = string("cannot monitor a subset of ") + name;
+	    msg = string("Cannot monitor a subset of ") + name;
 	}
 	
 	if (model->nchain() < 2) {
-	    msg = string("at least two parallel chains needed to monitor ")
+	    msg = string("At least two parallel chains needed to monitor ")
 		+ name;
 	    return 0;
 	}
@@ -47,17 +40,20 @@ namespace dic {
 	vector<StochasticNode const *> observed_nodes;
 	vector<StochasticNode *> const &snodes = model->stochasticNodes();
 	for (unsigned int i = 0; i < snodes.size(); ++i) {
-	    if (snodes[i]->isObserved()) {
+	    if (snodes[i]->isFixed()) {
 		if (isSupportFixed(snodes[i])) {
 		    observed_nodes.push_back(snodes[i]);
 		}
 		else {
+		    msg = "Support of observed nodes is not fixed";
 		    return 0;
 		}
 	    }
 	}
-	if (observed_nodes.empty())
+	if (observed_nodes.empty()) {
+	    msg = "There are no observed stochastic nodes";
 	    return 0;
+	}
 
 	unsigned int nchain = model->nchain();
 	vector<RNG*> rngs;
@@ -65,25 +61,12 @@ namespace dic {
 	    rngs.push_back(model->rng(i));
 	}
 
-	vector<CalKL*> calkl;
-	for (unsigned int i = 0; i < observed_nodes.size(); ++i) {
-	    
-	    StochasticNode const *snode = observed_nodes[i];
-	    KL const *kl = findKL(snode->distribution()->name());
-	    if (kl) {
-		calkl.push_back(new CalKLExact(snode, kl));
-	    }
-	    else {
-		calkl.push_back(new CalKLApprox(snode, rngs, 10));
-	    }
-	}
-
 	Monitor *m = 0;
 	if (name =="pD") {
-	    m = new PDMonitor(observed_nodes, calkl);
+	    m = new PDMonitor(observed_nodes, rngs, 10);
 	}
 	else if (name == "popt") {
-	    m = new PoptMonitor(observed_nodes, calkl);
+	    m = new PoptMonitor(observed_nodes, rngs, 10);
 	}
 	if (m) {
 	    m->setName(name);
@@ -100,4 +83,5 @@ namespace dic {
     {
 	return "dic::PD";
     }
-}
+
+}}
