@@ -8,16 +8,17 @@
 class StochasticNode;
 class CalKL;
 
+namespace jags {
 namespace dic {
 
     class PoptMonitor : public PDMonitor {
 	std::vector<StochasticNode const*> _snodes;
     public:
 	PoptMonitor(std::vector<StochasticNode const *> const &snodes,
-		    std::vector<CalKL*> const &calkl);
-	double weight(unsigned int k, unsigned int ch) const;
+		    std::vector<RNG*> const &rngs, unsigned int nrep);
+	double weight(StochasticNode const *snode, unsigned int ch) const;
     };
 
-}
+}}
 
 #endif /* POPT_MONITOR_H_ */
