@@ -18,6 +18,8 @@ using std::string;
 using std::pair;
 using std::set;
 
+namespace jags {
+
 static bool isDirch(StochasticNode const *snode)
 {
     return snode->distribution()->name() == "ddirch";
@@ -163,9 +165,9 @@ namespace mix {
 	    if (isDirch(snodes[i])) {
 		/* We can't handle structural zeros in the Dirichlet
 		   distribution. This excludes Dirichlet nodes with
-		   unobserved parents
+		   non-fixed parents
 		*/
-		if (!snodes[i]->parents()[0]->isObserved()) {
+		if (!snodes[i]->parents()[0]->isFixed()) {
 		    return false;
 		}
 		double const *par = snodes[i]->parents()[0]->value(0);
@@ -183,11 +185,6 @@ namespace mix {
 	return true;
     }
 
-    string NormMix::name() const
-    {
-	return "NormMix";
-    }
-
     void NormMix::getValue(vector<double> &x) const 
     {
 	_gv->getValue(x, _chain);
@@ -240,4 +237,5 @@ namespace mix {
     {
         return _gv->logLikelihood(_chain);
     }
-}
+
+}}
