@@ -7,6 +7,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace msm {
 
 Mexp::Mexp()
@@ -20,7 +21,8 @@ void Mexp::evaluate (double *value, vector<double const *> const &args,
     MatrixExpPade(value, args[0], dims[0][0], 1);
 }
 
-vector<unsigned int> Mexp::dim (vector <vector<unsigned int> > const &dims) const
+vector<unsigned int> Mexp::dim (vector <vector<unsigned int> > const &dims,
+				vector<double const *> const &values) const
 {
     return dims[0];
 }
@@ -30,4 +32,4 @@ bool Mexp::checkParameterDim (vector <vector<unsigned int> > const &dims) const
     return isSquareMatrix(dims[0]);
 }
 
-}
+}}
