@@ -6,8 +6,8 @@
 #include <compiler/ParseTree.h>
 #include <sarray/SArray.h>
 
-bool readRData(std::vector<ParseTree*> const *r_assignment_list, 
-	       std::map<std::string, SArray> &table,
+bool readRData(std::vector<jags::ParseTree*> const *r_assignment_list, 
+	       std::map<std::string, jags::SArray> &table,
                std::string &rngname);
 
 #endif /* READ_DATA_H_ */
